@@ -5,7 +5,7 @@ Tk::IDElayout - Tk Widget for Layout of Frames Similar to an IDE.
 
 =head1 SYNOPSIS
 
-B<Simple Example>: (See t/simpleIDElayout2.t in the source distribution for complete example)
+B<Simple Example>: (See t/simpleIDElayout2.t in the source distrubution for complete example)
 
         #### This example creates two IDEtabFrames for managing with IDElayout #####
         my $TOP = MainWindow->new;
@@ -83,7 +83,7 @@ B<Simple Example>: (See t/simpleIDElayout2.t in the source distribution for comp
 =head1 DESCRIPTION
 
 This is a widget for managing the layout of Tk frames (and other widgets) like an IDE (Integrated Development Environment)
-like I<Eclipse> or I<Microsoft Visual Studio>.
+like I<Ecliplse> or I<Microsoft Visual Studio>.
 
 B<Features:>
 
@@ -361,7 +361,7 @@ The last side of the frame (e.g. left, right, top, bot) that the mouse pointer w
 
 package Tk::IDElayout;
 
-our ($VERSION) = ('0.37_02');
+our ($VERSION) = ('0.3');
 
 use strict;
 
@@ -398,8 +398,6 @@ sub Populate {
 	my $widgets;
 	if ( defined( $args->{-widgets} ) ) {
 		$widgets = $args->{-widgets};
-                $cw->{Configure}{-widgets} = $widgets; # Make sure $widgets is populated before other options
-
 	}
 	else {
 		croak("Error: -widgets not supplied when creating IDElayout widget\n");
@@ -417,17 +415,12 @@ sub Populate {
             ];
         
 	# Create Placeholder frames
-        # We use the grid geometry manager here for better control
-        #    Using the pack geom manager, the status line along the bottom would disappear when
-        #    the frame was shrunk vertically.
-	my $menuFrame       = $cw->Frame()->grid( -column => 0, -row => 0, -sticky => 'ew');
-	my $toolbarFrame    = $cw->Frame()->grid( -column => 0, -row => 1, -sticky => 'ew');
-	my $mainPW          = $cw->Frame()->grid( -column => 0, -row => 2, -sticky => 'nsew');
-	my $statusLineFrame = $cw->Frame()->grid( -column => 0, -row => 3, -sticky => 'ew');
-
-        # 
-        $cw->gridColumnconfigure(0, -weight => 1); # Allow the whole column to expand
-        $cw->gridRowconfigure(2, -weight => 1); # The mainPW window can expand, anything else doesn't
+	my $menuFrame       = $cw->Frame()->pack(-side => 'top', -fill => 'x', -expand => 0);
+	my $toolbarFrame    = $cw->Frame()->pack(-side => 'top', -fill => 'x', -expand => 0);
+	my $mainPW          = $cw->Frame()->pack(-side => 'top', -fill => 'both', -expand => 1);
+	my $statusLineFrame = $cw->Frame()->pack(-side => 'top', -fill => 'x', -expand => 0);
+	
+	
 	
 	$cw->SUPER::Populate($args);
 	$cw->ConfigSpecs(	
@@ -539,7 +532,7 @@ sub frameStructure{
 	}
 	
 	# Create the directed graph structure used to store the layout
-	my $frameGraph = Graph::Directed->new;
+	my $frameGraph = Graph::Directed->new();
 
  	# Build Graph Struct
 	foreach my $node (@$nodes) {  # Build Nodes
@@ -551,7 +544,7 @@ sub frameStructure{
 			next if ( $attrName eq 'name' );    # skip name, we are already using that for the vertex name
 			$attr->{$attrName} = $node->{$attrName};
 		}
-		$frameGraph->set_vertex_attribute($node->{name}, 'attr', $attr);
+		$frameGraph->set_attribute( 'attr', $node->{name}, $attr );
 	}
 	foreach my $edge (@$edges) {  # Build Edges
 		$frameGraph->add_edge(@$edge);
@@ -608,13 +601,13 @@ sub populateWindow{
 	my $widgets = shift;
 	
 	# Create Paned Window
-	my $attr = $frameStruct->get_vertex_attribute($name, 'attr'); # Get the attribute hash
+	my $attr = $frameStruct->get_attribute('attr', $name); # Get the attribute hash
 	my $dir =  ($attr->{dir} =~ /v/i) ? 'vertical' : 'horiz';
 	
 	my @kids = $frameStruct->successors($name);  # get the childs
 	my $childOrder = $attr->{childOrder}; # Get the order of the childs
 		
-        my $expandfactors = $attr->{expandfactors} || [map 0, @$childOrder]; # Resize behavior of the childs, defaults to all zeroes
+        my $expandfactors = $attr->{expandfactors} || [map 0, @$childOrder]; # Resize behavoir of the childs, defaults to all zeros
         
 
         my $IDEpanedwindowConfig = $cw->cget(-IDEpanedwindowConfig);
@@ -627,7 +620,7 @@ sub populateWindow{
 	my @widgetsToAdd;
         my $childIndex = 0;
 	foreach my $childName(@$childOrder){	
-		my $childAttr = $frameStruct->get_vertex_attribute($childName, 'attr');
+		my $childAttr = $frameStruct->get_attribute('attr', $childName);
 		if( defined( $childAttr->{childOrder})){ # Another paned window, recurse
 			my $childPW = $cw->populateWindow($pw, $top, $frameStruct, $childName, $widgets);
 			push @widgetsToAdd, $childPW;
@@ -677,7 +670,7 @@ sub menu{
 	my $menuFrame = $cw->Subwidget('menuFrame');
 
 	$menu->pack(-in => $menuFrame, -side => 'top', -fill => 'x', -expand => 0);	
-	$menu->raise(); # Raise needed, because menuFrame might have been created after menu, and it would obscure the menu
+	$menu->raise(); # Raise needed, because menuFrame might have been created after menu, and it would obsure the menu
 	
 }
 
@@ -698,7 +691,7 @@ sub statusLine{
 	my $statusLineFrame = $cw->Subwidget('statusLineFrame');
 
 	$statusLine->pack(-in => $statusLineFrame, -side => 'bottom', -expand => 'no', -fill => 'x', -anchor => 'sw');
-	$statusLine->raise(); # Raise needed, because statusLineFrame might have been created after statusLine, and it would obscure the menu
+	$statusLine->raise(); # Raise needed, because statusLineFrame might have been created after statusLine, and it would obsure the menu
 	
 }
 
@@ -719,7 +712,7 @@ sub toolbar{
 	my $toolbarFrame = $cw->Subwidget('toolbarFrame');
 
 	$toolbar->pack(-in => $toolbarFrame, -side => 'top', -fill => 'x', -expand => 0);	
-	$toolbar->raise(); # Raise needed, because Frame might have been created after widget, and it would obscure the widget
+	$toolbar->raise(); # Raise needed, because Frame might have been created after widget, and it would obsure the widget
 	
 	
 }
@@ -1031,7 +1024,7 @@ sub addWidgetAtSide{
 	if ( defined($parent) ) {
 
 		# Find parent direction
-		my $pAttr = $frameStruct->get_vertex_attribute($parent, 'attr');
+		my $pAttr = $frameStruct->get_attribute( 'attr', $parent );
 		my $dir   = $pAttr->{dir} || '';
 		if (     $dir eq 'H' && ( $currentSide eq 'left' || $currentSide eq 'right' )
 		      || $dir eq 'V' && ( $currentSide eq 'top'  || $currentSide =~ 'bot' ) ) {
@@ -1050,7 +1043,7 @@ sub addWidgetAtSide{
 			}
 
 			my $childOrder    = $pAttr->{childOrder};
-			my $expandfactors = $pAttr->{expandfactors} || [map 0, @$childOrder]; # default expandFactors is all zeroes
+			my $expandfactors = $pAttr->{expandfactors} || [map 0, @$childOrder]; # default expandFactors is all zereoes
 
 			my $frameIndex;    # Frame index we are adding before/after
 
@@ -1199,7 +1192,7 @@ sub addWidgetAtSide{
 			# Add attributes for the new PW vertex in the frameStruct
 			my $attr = { dir => $dir, childOrder => [@newChildOrder],
                                      expandfactors => [@newExpandfactors] };
-			$frameStruct->set_vertex_attribute($PWname, 'attr', $attr);
+			$frameStruct->set_attribute( 'attr', $PWname, $attr );
 
 			# Add edges for the leaf nodes
 			$frameStruct->add_edge( $PWname, $widgetName );
@@ -1221,7 +1214,7 @@ sub addWidgetAtSide{
 
         $self->adjustGeom if( $self->cget(-ResizeOnReconfig)); # Resize to requested width/height if ResizeOnConfig true
         
-        # Fix the Dropsites so that the IDELayout dropsite is always last in the order
+        # Fix the Dropsites so that the IDELayout dropsite is allways last in the order
         #   Otherwise, the background IDElayout dropsites will show up first before others
         #    (like the IDEtabFrame dropsites).
         my $DropSites = $self->toplevel->{DropSites}{Local};
@@ -1258,7 +1251,7 @@ sub _createNewPWname{
         my @pwNodes;
         # Find the PaneWindow nodes
         foreach my $node(@nodes){
-                my $attr = $frameGraph->get_vertex_attribute($node, 'attr'); # Get the attribute hash
+                my $attr = $frameGraph->get_attribute('attr', $node); # Get the attribute hash
                 push @pwNodes, $node if( defined($attr->{childOrder}));
         }
         
@@ -1359,7 +1352,7 @@ sub simplifyAfterDelete{
 	$frameStruct->delete_vertex($frameName);
 	
 	# Remove frame from parent childorder
-	my $pwAttr = $frameStruct->get_vertex_attribute($pwName, 'attr');
+	my $pwAttr = $frameStruct->get_attribute( 'attr', $pwName );
 	my $childOrder = $pwAttr->{childOrder};
 	@$childOrder = grep $_ ne $frameName, @$childOrder;
 	
@@ -1376,7 +1369,7 @@ sub simplifyAfterDelete{
 		my ($p2Name) = $frameStruct->predecessors($pwName);
 		if( $p2Name){ 
 			my $p2 = $widgets->{$p2Name};
-			my $p2Attr = $frameStruct->get_vertex_attribute($p2Name, 'attr');
+			my $p2Attr = $frameStruct->get_attribute( 'attr', $p2Name );
 
 
 			# Find Parents place in Parents's parent (p2)
@@ -1469,11 +1462,13 @@ sub displayStruct{
         
 	my $g = new GraphViz;
 	my @edges = $graph->edges();
-
-	foreach my $edge (@edges) {
-		$g->add_edge(@$edge);
+	
+	while (@edges){
+		my $from = shift @edges;
+		my $to   = shift @edges;
+		$g->add_edge($from,$to);
 	}
-
+	
 	my $gviewer = $self->Toplevel->GraphVizViewer( 
  	-graphviz => $g,
 	-nodefill => 'lightsteelblue1',
@@ -1485,7 +1480,7 @@ sub displayStruct{
 	 print "#########################\n";
 	 foreach my $widget(sort keys %$widgets){
 		 if( $widget =~ /^P\d+/){
-			 my $attr = $graph->get_vertex_attribute($widget, 'attr'); # Get the attribute hash
+			 my $attr = $graph->get_attribute('attr', $widget); # Get the attribute hash
 			 my $dir =  $attr->{dir};
 			 my $childOrder = $attr->{childOrder};
 			 print "$widget: $dir  ".join(", ", @$childOrder)."\n";
