@@ -176,14 +176,13 @@ is used as a "dropbox" where the source can put a object in this hash, key'ed by
 name is passed to the target (i.e. the drop location). The target can use the string to lookup the
 real object in this hash.
 
-=back
 
 =head1 Methods
 
 =cut
 
 package Tk::IDEtabFrame;
-our ($VERSION) = ('0.37_02');
+our ($VERSION) = ('0.3');
 
 use Carp;
 use strict;
@@ -595,7 +594,7 @@ sub endDrag {
 			$contents->wmRelease;
 			# MainWindow needed here because wmReleased widget don't properly inherit from
 			#   Tk::Toplevel
-			$contents->MainWindow::attributes(-toolwindow => 1) if ($^O eq 'MSWin32');
+			$contents->MainWindow::attributes(-toolwindow => 1) if( $^O =~ /mswin32/i);
 			$contents->MainWindow::title($caption);
 			$contents->MainWindow::geometry($geometry);
  			$contents->MainWindow::deiconify;
@@ -722,7 +721,7 @@ sub drop{
 	
 	print "DragSource = $DragSource\n" if($DEBUG);
 	
-	# Callback to add new tab
+	# Calback to add new tab
 	my $addAction =
 		sub{
 			my $newFrame = $self->add(
@@ -901,7 +900,7 @@ sub endDragTW {
 	my $newgeom = $shadow->geometry();
 	print "In End Command\n" if($DEBUG);
 
-	# Get the new root position of the window and set posX/Y, so we don't
+	# Get the new root positio of the window and set posX/Y, so we don't
 	#   get a false window move indication
 	my ( $newX, $newY ) = $newgeom =~ /(\d+)\+(\d+)$/;
 	if ( defined($newX) && defined($newY) && !$self->{dropped} )
@@ -961,13 +960,6 @@ If the tabclose option is 1, this installs a callback to our TabRemove, rather t
 Because L<Tk::DynaTabFrame> calls its I<TabRemove> directly (Using \&TabRemove), rather than by a method call, this tabclose method is
 needed to call our overriden I<TabRemove> method.
         
-The default code ref installed here is called when the close button pressed on the tab.
-It explicitly destroys the widget contained in the tab. This is needed because the widgets in IDElayout
-are created as childs of the main widget, and not childs of the IDEtabframe widget.
-This is done so the widgets can be dragged around in the GUI.
-
-Since the widgets are created as childs of the main window, and not the IDEtabframe tabs,
-just deleting the tab won't delete the widget. So we delete it manually here.
 
 =cut
 
@@ -977,36 +969,7 @@ sub tabclose {
 	return $this->SUPER::tabclose() unless defined($close);
 
         if (ref($close) ne 'CODE' && $close == 1){ # Default close button desired
-                
-                # This code ref called when the close button pressed on the tab
-                #   It destroys the widget contents. This is needed because the widgets in IDElayout
-                #   are created as childs of the main widget, and not childs of the IDEtabframe widget.
-                #   This is done so the widgets can be dragged around in the GUI.
-                #   Since the widgets are created as childs of the main window, and not the IDEtabframe tabs,
-                #    just deleting the tab won't delete the widget. So we delete it manually here.
-                my $subRef = sub{
-                        my $self = shift;
-                        my $tabName = shift;
-
-                        # Make lookup of client names to client frames
-                        my $clientHash = $self->{ClientHash};
-                        my $clientList = $self->{ClientList};
-                        my @clientFrames =  map $clientList->[$clientHash->{$_}][0], keys %$clientHash;
-                        
-                        my %clientFrames;
-                        @clientFrames{ keys %$clientHash} = @clientFrames;
-                        
-                        my $clientFrame = $clientFrames{$tabName};
-                        #print "clientFrame = $clientFrame\n";
-                        
-                        # get the frame contents, explicitly destroy it
-                        my ($pageContents) = $clientFrame->packSlaves();
-                        $pageContents->destroy();
-                        
-                        #print "Page contents = $pageContents\n";
-                        
-                        $self->TabRemove($tabName)
-                }; # Sub ref to call our TabRemove
+                my $subRef = sub{ my $self = shift; $self->TabRemove(@_)}; # Sub ref to call our TabRemove
                 return $this->SUPER::tabclose($subRef);
         }
         
